from distutils.core import setup

setup(
	name    = 'RaviSharma1',
	version = '1.0.0',
	py_modules = ['RaviSharma1'],
	author = 'RaviSharma',
	author_email = 'ravi15165@iiitd.ac.in',
	url = 'http://www.headfirstlabs.com',
	description = 'A simple printer nested list', 
	)
